/**
 * @file Ce fichier gère les authentifications sur le back de façon à assurer la persistence des différentes connections.
 * @author manifold
 */


import passport from 'passport';
import '../config_passport';
import jwt from 'jsonwebtoken';

// JSON web token secret key (sale)
const SECRET_KEY = "boom shakalaka";

/**
 * * @summary Fonction identifiant l'utilisateur contre le LDAP using passportjs (http://www.passportjs.org/).
 * Cette promesse échouera si aucun utilisateur n'est renvoyé par passport.authenticate.
 * @arg {String} username - Identifiant de l'utilisateur.
 * @arg {String} password - Mot de passe de l'utilisateur, transmis du front par https.
 * @arg {String} req - Requête que l'utilisateur désire faire ? 
 * @return {Promise(Object)} Promesse de token d'identification
 */
const loginResolverFunc = ({ username, password, req }) => {
    return new Promise((resolve, reject) => {
        passport.authenticate('ldapauth', (err, user, info) => {
            if (err) { reject(err); }
            if (!user) { reject('Invalid credentials.'); }

            // Sign a new JSON web token with the user's uid against the secret key
            const token = jwt.sign({ uid: user.uid }, SECRET_KEY);
            resolve(token);
        })({ body: { username, password } });
    });
};

export default loginResolverFunc;